==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/sites/lang/sites_he.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'En attente', # NEW
	'articles_meme_auteur' => 'Tous les articles de cet auteur', # NEW
	'articles_off' => 'Bloqués', # NEW
	'articles_publie' => 'Publiés', # NEW
	'articles_refuse' => 'Supprimés', # NEW
	'articles_tous' => 'Tous', # NEW
	'aucun_article_syndic' => 'Aucun article syndiqué', # NEW
	'avis_echec_syndication_01' => 'נכשלה הסינדיקציה :את  הbackend אי אפשר לפענח או אינו כולל שום מאמר.',
	'avis_echec_syndication_02' => 'נכשלה הסינדיקציה : אי אפשר להיכנס לbackend של האתר',
	'avis_site_introuvable' => 'אתר לא נמצא',
	'avis_site_syndique_probleme' => 'אזהרה: הסינדיקציה של האתר הזה נתקלה בבעיה; כתוצאה מכך המערכת מנותקת זמנית. נא אשר את הכתובת של קובץ הסינדיקציה של האתר הזה(<b>@url_syndic@</b>), ונסה עוד פעם לבצע החזרה חדשה של האינפורמציה',
	'avis_sites_probleme_syndication' => '.האתרים האלה נתקלו בבעיית סינדיקציה ',
	'avis_sites_syndiques_probleme' => 'אתרי הסינדיקציה האלה יצרו בעיה',

	// B
	'bouton_exporter' => 'Exporter', # NEW
	'bouton_importer' => 'Importer', # NEW
	'bouton_radio_modere_posteriori' => 'צמצום לאחר מכן',
	'bouton_radio_modere_priori' => 'צמצום מראש',
	'bouton_radio_non_syndication' => 'אין סינדיקציה',
	'bouton_radio_syndication' => ':סינדיקציה',

	// C
	'confirmer_purger_syndication' => 'Êtes-vous certain de vouloir supprimer tous les articles syndiqués de ce site ?', # NEW

	// E
	'entree_adresse_fichier_syndication' => 'כתובת קובץ הסינדיקציה :',
	'entree_adresse_site' => '<b>כתובת האתר</b> [Obligatoire]',
	'entree_description_site' => 'תיאור האתר',
	'erreur_fichier_format_inconnu' => 'Le format du fichier @fichier@ n\'est pas pris en charge.', # NEW
	'erreur_fichier_incorrect' => 'Impossible de lire le fichier.', # NEW

	// F
	'form_prop_nom_site' => 'שם האתר',

	// I
	'icone_article_syndic' => 'Article syndiqué', # NEW
	'icone_articles_syndic' => 'Articles syndiqués', # NEW
	'icone_controler_syndication' => 'Publication des articles syndiqués', # NEW
	'icone_modifier_site' => 'שנה את האתר הזה',
	'icone_referencer_nouveau_site' => 'ייחס אתר חדש',
	'icone_site_reference' => 'Sites référencés', # NEW
	'icone_supprimer_article' => 'Supprimer cet article', # NEW
	'icone_supprimer_articles' => 'Supprimer ces articles', # NEW
	'icone_valider_article' => 'Valider cet article', # NEW
	'icone_valider_articles' => 'Valider ces articles', # NEW
	'icone_voir_sites_references' => 'הצג אתרים עם מראי מקום',
	'info_1_site_importe' => '1 site a été importé', # NEW
	'info_a_valider' => '[לאישור]',
	'info_aucun_site_importe' => 'Aucun site n\'a pu être importé', # NEW
	'info_bloquer' => 'חסום',
	'info_bloquer_lien' => 'חסום את הקישור הזה',
	'info_derniere_syndication' => 'הסינדיקציה האחרונה של האתר הזה בוצעה',
	'info_liens_syndiques_1' => 'קישורים עם סינדיקציה',
	'info_liens_syndiques_2' => '.מחכה למתן תוקף חוקי',
	'info_nb_sites_importes' => '@nb@ sites ont été importés', # NEW
	'info_nom_site_2' => '<b>Nom du site</b> [Obligatoire]', # NEW
	'info_panne_site_syndique' => 'אתר עם סינדיקציה מקולקל',
	'info_probleme_grave' => 'שגיאה של',
	'info_question_proposer_site' => '?מי יכול להציע אתרים עם מראי מקום',
	'info_retablir_lien' => 'החזרת קישור זה',
	'info_site_attente' => 'האתר בציפיית הוולידציה',
	'info_site_propose' => 'Site proposé le :', # NEW
	'info_site_reference' => 'מראי מקום אתרים מקוונים',
	'info_site_refuse' => 'האתר נדחה',
	'info_site_syndique' => 'Ce site est syndiqué...', # NEW
	'info_site_valider' => 'אתרים כדי לאמת',
	'info_sites_referencer' => 'הוספת אתר למראי מקום',
	'info_sites_refuses' => 'Les sites refusés', # NEW
	'info_statut_site_1' => 'אתר זה :',
	'info_statut_site_2' => 'לאור',
	'info_statut_site_3' => 'המוצעת',
	'info_statut_site_4' => 'לפח',
	'info_syndication' => 'סינדיקציה:',
	'info_syndication_articles' => 'מאמר(ים)',
	'item_bloquer_liens_syndiques' => 'Bloquer les liens syndiqués pour validation', # NEW
	'item_gerer_annuaire_site_web' => 'Gérer un annuaire de sites Web', # NEW
	'item_non_bloquer_liens_syndiques' => 'Ne pas bloquer les liens issus de la syndication', # NEW
	'item_non_gerer_annuaire_site_web' => 'Désactiver l\'annuaire de sites Web', # NEW
	'item_non_utiliser_syndication' => 'Ne pas utiliser la syndication automatique', # NEW
	'item_utiliser_syndication' => 'Utiliser la syndication automatique', # NEW

	// L
	'label_exporter_avec_mots_cles_1' => 'Exporter les mots-clés sous forme de tags', # NEW
	'label_exporter_id_parent' => 'Exporter les sites de la rubrique', # NEW
	'label_exporter_publie_seulement_1' => 'Exporter uniquement les sites publiés', # NEW
	'label_fichier_import' => 'Fichier HTML', # NEW
	'label_importer_les_tags_1' => 'Importer les tags sous forme de mot-clé', # NEW
	'label_importer_statut_publie_1' => 'Publier automatiquement les sites', # NEW
	'lien_mise_a_jour_syndication' => 'Mettre à jour maintenant', # NEW
	'lien_nouvelle_recuperation' => 'Tenter une nouvelle récupération des données', # NEW
	'lien_purger_syndication' => 'Effacer tous les articles syndiqués', # NEW

	// N
	'nombre_articles_syndic' => '@nb@ articles syndiqués', # NEW

	// S
	'statut_off' => 'Supprimé', # NEW
	'statut_prop' => 'En attente', # NEW
	'statut_publie' => 'Publié', # NEW
	'syndic_choix_moderation' => 'Que faire des prochains liens en provenance de ce site ?', # NEW
	'syndic_choix_oublier' => 'Que faire des liens qui ne figurent plus dans le fichier de syndication ?', # NEW
	'syndic_choix_resume' => 'Certains sites diffusent le texte complet des articles. Lorsque celui-ci est disponible souhaitez-vous syndiquer :', # NEW
	'syndic_lien_obsolete' => 'lien obsolète', # NEW
	'syndic_option_miroir' => 'les bloquer automatiquement', # NEW
	'syndic_option_oubli' => 'les effacer (après @mois@ mois)', # NEW
	'syndic_option_resume_non' => 'le contenu complet des articles (au format HTML)', # NEW
	'syndic_option_resume_oui' => 'un simple résumé (au format texte)', # NEW
	'syndic_options' => 'Options de syndication :', # NEW

	// T
	'texte_expliquer_export_bookmarks' => 'Vous pouvez exporter une liste de sites au format Marque-page HTML,
	pour vous permettre ensuite de l\'importer dans votre navigateur ou dans un service en ligne', # NEW
	'texte_expliquer_import_bookmarks' => 'Vous pouvez importer une liste de sites au format Marque-page HTML,
	en provenance de votre navigateur ou d\'un service en ligne de gestion des Marques-pages.', # NEW
	'texte_liens_sites_syndiques' => 'Les liens issus des sites syndiqués peuvent
			être bloqués a priori ; le réglage
			ci-dessous indique le réglage par défaut des
			sites syndiqués après leur création. Il
			est ensuite possible, de toutes façons, de
			débloquer chaque lien individuellement, ou de
			choisir, site par site, de bloquer les liens à venir
			de tel ou tel site.', # NEW
	'texte_messages_publics' => 'Messages publics de l\'article :', # NEW
	'texte_non_fonction_referencement' => 'Vous pouvez préférer ne pas utiliser cette fonction automatique, et indiquer vous-même les éléments concernant ce site...', # NEW
	'texte_referencement_automatique' => '<b>Référencement automatisé d\'un site</b><br />Vous pouvez référencer rapidement un site Web en indiquant ci-dessous l\'adresse URL désirée, ou l\'adresse de son fichier de syndication. SPIP va récupérer automatiquement les informations concernant ce site (titre, description...).', # NEW
	'texte_referencement_automatique_verifier' => 'Veuillez vérifier les informations fournies par <tt>@url@</tt> avant d\'enregistrer.', # NEW
	'texte_syndication' => 'Il est possible de récupérer automatiquement, lorsqu\'un site Web le permet, 
		la liste de ses nouveautés. Pour cela, vous devez activer la syndication. 
		<blockquote><i>Certains hébergeurs désactivent cette fonctionnalité ; 
		dans ce cas, vous ne pourrez pas utiliser la syndication de contenu
		depuis votre site.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Articles syndiqués tirés de ce site', # NEW
	'titre_dernier_article_syndique' => 'Derniers articles syndiqués', # NEW
	'titre_exporter_bookmarks' => 'Exporter des Marques-pages', # NEW
	'titre_importer_bookmarks' => 'Importer des Marques-pages', # NEW
	'titre_importer_exporter_bookmarks' => 'Importer et Exporter des Marques-pages', # NEW
	'titre_page_sites_tous' => 'Les sites référencés', # NEW
	'titre_referencement_sites' => 'Référencement de sites et syndication', # NEW
	'titre_site_numero' => 'SITE NUMÉRO :', # NEW
	'titre_sites_proposes' => 'Les sites proposés', # NEW
	'titre_sites_references_rubrique' => 'Les sites référencés dans cette rubrique', # NEW
	'titre_sites_syndiques' => 'Les sites syndiqués', # NEW
	'titre_sites_tous' => 'Les sites référencés', # NEW
	'titre_syndication' => 'Syndication de sites', # NEW
	'tout_voir' => 'Voir tous les articles syndiqués', # NEW

	// U
	'un_article_syndic' => '1 article syndiqué' # NEW
);

?>

==> spip_3.1~21100.orig.tar.xz: spip-3.1~21100.orig/plugins-dist/sites/lang/sites_he.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=he
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'נכשלה הסינדיקציה :את  הbackend אי אפשר לפענח או אינו כולל שום מאמר.',
	'avis_echec_syndication_02' => 'נכשלה הסינדיקציה : אי אפשר להיכנס לbackend של האתר',
	'avis_site_introuvable' => 'אתר לא נמצא',
	'avis_site_syndique_probleme' => 'אזהרה: הסינדיקציה של האתר הזה נתקלה בבעיה; כתוצאה מכך המערכת מנותקת זמנית. נא אשר את הכתובת של קובץ הסינדיקציה של האתר הזה(<b>@url_syndic@</b>), ונסה עוד פעם לבצע החזרה חדשה של האינפורמציה',
	'avis_sites_probleme_syndication' => '.האתרים האלה נתקלו בבעיית סינדיקציה ',
	'avis_sites_syndiques_probleme' => 'אתרי הסינדיקציה האלה יצרו בעיה',

	// B
	'bouton_radio_modere_posteriori' => 'צמצום לאחר מכן', # MODIF
	'bouton_radio_modere_priori' => 'צמצום מראש', # MODIF
	'bouton_radio_non_syndication' => 'אין סינדיקציה',
	'bouton_radio_syndication' => ':סינדיקציה',

	// E
	'entree_adresse_fichier_syndication' => 'כתובת קובץ הסינדיקציה :',
	'entree_adresse_site' => '<b>כתובת האתר</b> [Obligatoire]',
	'entree_description_site' => 'תיאור האתר',

	// F
	'form_prop_nom_site' => 'שם האתר',

	// I
	'icone_modifier_site' => 'שנה את האתר הזה',
	'icone_referencer_nouveau_site' => 'ייחס אתר חדש',
	'icone_voir_sites_references' => 'הצג אתרים עם מראי מקום',
	'info_1_site' => 'אתר 1',
	'info_a_valider' => '[לאישור]',
	'info_bloquer' => 'חסום',
	'info_bloquer_lien' => 'חסום את הקישור הזה',
	'info_derniere_syndication' => 'הסינדיקציה האחרונה של האתר הזה בוצעה',
	'info_liens_syndiques_1' => 'קישורים עם סינדיקציה',
	'info_liens_syndiques_2' => '.מחכה למתן תוקף חוקי',
	'info_panne_site_syndique' => 'אתר עם סינדיקציה מקולקל',
	'info_probleme_grave' => 'שגיאה של',
	'info_question_proposer_site' => '?מי יכול להציע אתרים עם מראי מקום',
	'info_retablir_lien' => 'החזרת קישור זה',
	'info_site_attente' => 'האתר בציפיית הוולידציה',
	'info_site_reference' => 'מראי מקום אתרים מקוונים',
	'info_site_refuse' => 'האתר נדחה',
	'info_site_valider' => 'אתרים כדי לאמת',
	'info_sites_referencer' => 'הוספת אתר למראי מקום',
	'info_statut_site_1' => 'אתר זה :',
	'info_statut_site_2' => 'לאור',
	'info_statut_site_3' => 'המוצעת',
	'info_statut_site_4' => 'לפח', # MODIF
	'info_syndication' => 'סינדיקציה:',
	'info_syndication_articles' => 'מאמר(ים)',

	// T
	'texte_syndication' => 'Il est possible de récupérer automatiquement, lorsqu’un site Web le permet, 
		la liste de ses nouveautés. Pour cela, vous devez activer la syndication. 
		<blockquote><i>Certains hébergeurs désactivent cette fonctionnalité ; 
		dans ce cas, vous ne pourrez pas utiliser la syndication de contenu
		depuis votre site.</i></blockquote>' # MODIF
);

?>
